@@ -1,4 +1,5 @@
 """:obj:`openqlab.ServoDesign` helps with designing a standard servo circuit."""
+
 from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 from warnings import warn
@@ -7,10 +8,8 @@ import numpy as np
 import pandas as pd
 from matplotlib.figure import Figure
 from numpy import ndarray
-from pandas import DataFrame, Series
-from pandas.core.indexes.numeric import Float64Index
+from pandas import DataFrame, Index, Series
 from scipy import signal
-from tabulate import tabulate  # type: ignore
 
 from openqlab import plots
 from openqlab.conversion import db
@@ -279,13 +278,13 @@ class Lowpass(Filter):
         second_parameter = self.second_parameter
         p: List[complex] = [
             -corner_frequency / (2 * second_parameter)
-            + ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency ** 2)
+            + ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency**2)
             ** 0.5,
             -corner_frequency / (2 * second_parameter)
-            - ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency ** 2)
+            - ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency**2)
             ** 0.5,
         ]
-        k = corner_frequency ** 2
+        k = corner_frequency**2
 
         return z, p, k
 
@@ -332,10 +331,10 @@ class Notch(Filter):
         z = [corner_frequency * 1j, -corner_frequency * 1j]
         p = [
             -corner_frequency / (2 * second_parameter)
-            + ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency ** 2)
+            + ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency**2)
             ** 0.5,
             -corner_frequency / (2 * second_parameter)
-            - ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency ** 2)
+            - ((corner_frequency / (2 * second_parameter)) ** 2 - corner_frequency**2)
             ** 0.5,
         ]
         k = 1
@@ -673,7 +672,7 @@ class ServoDesign:
 
     def _apply(
         self,
-        freq: Union[ndarray, Float64Index],
+        freq: Union[ndarray, Index],
         ampl: Optional[Series] = None,
         phase: Optional[Series] = None,
     ) -> DataFrame:
@@ -808,10 +807,17 @@ class ServoDesign:
             ["zeros", "poles", "gain"],
             ["Gain", [], [], self.gain],
         ]
-        return tabulate(
-            description + data,
-            headers="firstrow",
-        )
+        desc_data = description + data
+
+        return str(desc_data)
+
+        # FIXME: tabulate stopped working with current numpy and is not really maintained anymore
+        # https://github.com/astanin/python-tabulate/issues/287
+
+        # return tabulate(
+        #     desc_data,
+        #     headers="firstrow",
+        # )
 
     def __getstate__(
         self,
