@@ -11,7 +11,7 @@ log = logging.getLogger(__name__)
 
 
 try:
-    from uncertainties import ufloat, umath, core
+    from uncertainties import core, ufloat, umath
 
     _DATA_TYPES = Union[float, list, np.ndarray, ufloat]
     UNCERTAINTIES = True
@@ -95,8 +95,7 @@ def max(loss: _DATA_TYPES, initial: _DATA_TYPES = -20, antisqz: bool = False):
     if antisqz:
         antisqz_ = db.from_lin(db.to_lin(-initial) * (1 - loss) + loss)
         return [sqz, antisqz_]
-    else:
-        return sqz
+    return sqz
 
 
 def _ensure_np_array(value):
