@@ -27,13 +27,13 @@ from pandas.core.frame import DataFrame
 from openqlab._typing import FilepathOrBuffer
 
 
-@contextlib.contextmanager
+@contextlib.contextmanager  # type:ignore
 @overload
 def _open_file_or_buff(filepath_or_buffer: None, mode: str) -> ContextManager[StringIO]:
     pass  # overloaded
 
 
-@contextlib.contextmanager
+@contextlib.contextmanager  # type: ignore
 @overload
 def _open_file_or_buff(
     filepath_or_buffer: StringIO, mode: str
@@ -41,7 +41,7 @@ def _open_file_or_buff(
     pass  # overloaded
 
 
-@contextlib.contextmanager
+@contextlib.contextmanager  # type: ignore
 @overload
 def _open_file_or_buff(
     filepath_or_buffer: FilepathOrBuffer, mode: str
@@ -177,7 +177,7 @@ class MetaDataContainer(type):
         "rmod",
         "rpow",
     ]
-    combining = ["append", "join", "merge", "combine", "combine_first"]
+    combining = ["join", "merge", "combine", "combine_first"]
     indexing = [
         "isin",
         # "where",
@@ -471,7 +471,7 @@ class DataContainer(DataContainerBase, pd.DataFrame, metaclass=MetaDataContainer
     def read_csv(
         cls, filepath_or_buffer: FilepathOrBuffer, *args, index_col=0, **kwargs
     ) -> "DataContainer":
-        with _open_file_or_buff(filepath_or_buffer, mode="r") as file:
+        with _open_file_or_buff(filepath_or_buffer, mode="r") as file:  # type:ignore
             header_dict = cls._json_to_header(file)
             df = pd.read_csv(file, *args, index_col=index_col, **kwargs)
             if header_dict and kwargs.get("header", "infer"):
@@ -516,7 +516,9 @@ class DataContainer(DataContainerBase, pd.DataFrame, metaclass=MetaDataContainer
         cls, filepath_or_buffer: FilepathOrBuffer, *args, orient=None, **kwargs
     ) -> "DataContainer":
         try:
-            with _open_file_or_buff(filepath_or_buffer, mode="r") as file:
+            with _open_file_or_buff(  # type:ignore
+                filepath_or_buffer, mode="r"
+            ) as file:
                 header_dict = cls._json_to_header(file)
                 return DataContainer(
                     pd.read_json(file, *args, orient=orient, **kwargs),
