@@ -7,7 +7,7 @@ class DataContainerCSV(StreamImporter):
     AUTOIMPORTER = True
     STARTING_LINES = [DataContainer.JSON_PREFIX.strip()]
 
-    def read(self):
+    def read(self) -> DataContainer:
         self._stream.seek(0)
         output = DataContainer.from_csv(self._stream, parse_dates=True)
         return output
