@@ -84,8 +84,8 @@ class Gwinstek_LSF(StreamImporter):
 
         data = np.fromfile(self._stream, dtype="int16")
         index = self.construct_x_axis()
-        data = pd.DataFrame(data, index=index, columns=[ylabel])
-        data.index.name = xlabel
-        data = (data - y_offset) * y_scale
+        df = pd.DataFrame(data, index=index, columns=[ylabel])
+        df.index.name = xlabel
+        df = (df - y_offset) * y_scale
 
-        return data
+        return df
