@@ -21,9 +21,7 @@ class KeysightCSV(StreamImporter):
     def _read_data(self) -> DataFrame:
         xlabel = "Time"
         ylabel = utils.get_file_basename(self._stream.name)
-        output = pd.read_csv(
-            self._stream, sep=",", index_col=0, prefix=ylabel + "_", header=None
-        )
+        output = pd.read_csv(self._stream, sep=",", index_col=0, header=None)
         output.index.name = xlabel
 
         return output
