@@ -13,7 +13,4 @@ def stepspace(start: float, step: float, num: int, axis=0) -> NDArray:
     stop = start + (step * num)
 
     space, retstep = linspace(start, stop, num, endpoint=False, retstep=True, axis=axis)
-    assert (
-        step == retstep
-    ).all(), "This should never be happening, please report a bug!"
     return space
